| Title: | Administrative Boundaries of Senegal |
|---|---|
| Description: | The administrative boundaries of Senegal are provided at several levels, including regions, departments, arrondissements and communes. The Global Administrative Areas database, or GADM <https://gadm.org/>, is the primary source for these layers. The dataset is complemented by the incorporation of additional geographic layers, such as localities, universities, roads, or health facility locations. |
| Authors: | Timothée Giraud [cre, aut] (ORCID: <https://orcid.org/0000-0002-1932-3323>), Labaly Touré [aut] (ORCID: <https://orcid.org/0009-0008-0939-2019>), Hugues Pecout [ctb] (ORCID: <https://orcid.org/0000-0002-0246-0954>, Logo), Robert J. Hijmans [cph] (ORCID: <https://orcid.org/0000-0001-5872-2872>, GADM database) |
| Maintainer: | Timothée Giraud <[email protected]> |
| License: | GPL-3 |
| Version: | 0.1.1 |
| Built: | 2026-06-07 07:17:43 UTC |
| Source: | https://github.com/mapsenegal/mapsenegal |
Arrondissements of Senegal.
GID_1: identifier for regions
GID_2: identifier for departments
GID_3: unique identifier for arrondissements
NAME: name of the arrondissement
CC_3: unknown code
sn_arrondissements()sn_arrondissements()
An sf object is returned.
Codes and geometries have been extracted from the GADM database v4.1 (https://gadm.org/). Geometries precision has been fixed to 1 meter.
ardt <- sn_arrondissements() plot(ardt) if (require("mapsf")) { mf_map(ardt) mf_title("Arrondissements of Senegal") }ardt <- sn_arrondissements() plot(ardt) if (require("mapsf")) { mf_map(ardt) mf_title("Arrondissements of Senegal") }
Communes of Senegal.
GID_1: identifier for regions
GID_2: identifier for departments
GID_3: identifier for arrondissements
GID_4: identifier for communes
NAME: name of the arrondissement
CC_4: unknown code
sn_communes()sn_communes()
An sf object is returned.
Codes and geometries have been extracted from the GADM database v4.1 (https://gadm.org/). Geometries precision has been fixed to 1 meter.
com <- sn_communes() plot(com) if (require("mapsf")) { mf_map(com) mf_title("Communes of Senegal") }com <- sn_communes() plot(com) if (require("mapsf")) { mf_map(com) mf_title("Communes of Senegal") }
Senegal, level-0 entity.
GID_0: unique identifier for countries
NAME: name of the country
sn_country()sn_country()
An sf object is returned.
Codes and geometries have been extracted from the GADM database v4.1 (https://gadm.org/). Geometries precision has been fixed to 1 meter.
senegal <- sn_country() plot(senegal) if (require("mapsf")) { mf_map(senegal) mf_title("Senegal") }senegal <- sn_country() plot(senegal) if (require("mapsf")) { mf_map(senegal) mf_title("Senegal") }
Departments of Senegal, level-2 entities.
GID_1: identifier for regions
GID_2: unique identifier for departments
NAME: name of the department
CC_2: unknown code
HASC_2: hierarchical administrative subdivision codes for level-2 entities
POP_RGPH5: 2023 population
POP_2024: 2024 population
sn_departments()sn_departments()
An sf object is returned.
Codes and geometries have been extracted from the GADM database v4.1 (https://gadm.org/). Geometries precision has been fixed to 1 meter.
dep <- sn_departments() plot(dep) if (require("mapsf")) { mf_map(dep) mf_title("Departments of Senegal") }dep <- sn_departments() plot(dep) if (require("mapsf")) { mf_map(dep) mf_title("Departments of Senegal") }
Health facilities of Senegal
NAME: health facility name
CC_1: unkown code
CC_2: unkown code
TYPE: health facility category
sn_health_facilities()sn_health_facilities()
An sf object is returned.
Direction des Travaux geographiques et de la cartographie, Senegal.
hf <- sn_health_facilities() plot(hf) if (require("mapsf")) { mf_map(hf, var = "TYPE", type = "symb", cex = 1, pal = "Dark 3", add = FALSE) mf_title("Health Facilities of Senegal") }hf <- sn_health_facilities() plot(hf) if (require("mapsf")) { mf_map(hf, var = "TYPE", type = "symb", cex = 1, pal = "Dark 3", add = FALSE) mf_title("Health Facilities of Senegal") }
Localites of Senegal.
NAME: locality name
CC_1: unkown code
CC_2: unkown code
sn_localities()sn_localities()
An sf object is returned.
Direction des Travaux geographiques et de la cartographie, Senegal.
loc <- sn_localities() plot(loc) if (require("mapsf")) { mf_map(loc) mf_title("Localities of Senegal") }loc <- sn_localities() plot(loc) if (require("mapsf")) { mf_map(loc) mf_title("Localities of Senegal") }
Neighboring countries of Senegal, level-0 entities.
GID_0: unique identifier for countries
NAME: name of the country
sn_neighbors()sn_neighbors()
An sf object is returned.
Codes and geometries have been extracted from the GADM database v4.1 (https://gadm.org/). Geometries precision has been fixed to 1 meter. Countries were cropped using a 100 km buffer around the Senegal bounding box.
neighbors <- sn_neighbors() plot(neighbors) if (require("mapsf")) { mf_map(neighbors) mf_label(neighbors, "NAME", halo = TRUE) mf_title("Senegal and Neighboring Countries") }neighbors <- sn_neighbors() plot(neighbors) if (require("mapsf")) { mf_map(neighbors) mf_label(neighbors, "NAME", halo = TRUE) mf_title("Senegal and Neighboring Countries") }
Regions of Senegal, level-1 entities.
GID_1: unique identifier for regions
NAME: name of the region
CC_1: unknown identifier
HASC_1: hierarchical administrative subdivision codes for level-1 entities
ISO: ISO codes for level-1 entities (ISO-3166-2)
POP_RGPH4: 20xx population
POP_RGPH5: 2023 population
sn_regions()sn_regions()
An sf object is returned.
Codes and geometries have been extracted from the GADM database v4.1 (https://gadm.org/). Geometries precision has been fixed to 1 meter.
reg <- sn_regions() plot(reg) if (require("mapsf")) { mf_map(reg) mf_title("Regions of Senegal") }reg <- sn_regions() plot(reg) if (require("mapsf")) { mf_map(reg) mf_title("Regions of Senegal") }
Roads of Senegal.
TYPE: road type. 1 for motorways, 2 for national roads, 3 for regional roads, 4 for departmental roads, 5 for other roads.
NAME: road name
sn_roads()sn_roads()
An sf object is returned.
Direction des Travaux geographiques et de la cartographie, Senegal.
roads <- sn_roads() plot(roads) if (require("mapsf")) { mf_map(roads, var = "TYPE", type = "typo", lwd = 2) mf_title("Roads of Senegal") }roads <- sn_roads() plot(roads) if (require("mapsf")) { mf_map(roads, var = "TYPE", type = "typo", lwd = 2) mf_title("Roads of Senegal") }
Universities of Senegal.
NAME: university name
NB_FACULTIES: number of faculties
NB_STUDENTS: number of students
sn_universities()sn_universities()
An sf object is returned.
Dataset gathered by Labaly Toure.
univ <- sn_universities() plot(univ) if (require("mapsf")) { mf_map(univ, var = "NB_STUDENTS", type = "prop", add = FALSE) mf_title("Universities of Senegal") }univ <- sn_universities() plot(univ) if (require("mapsf")) { mf_map(univ, var = "NB_STUDENTS", type = "prop", add = FALSE) mf_title("Universities of Senegal") }