The hardware and bandwidth for this mirror is donated by dogado GmbH, the Webhosting and Full Service-Cloud Provider. Check out our Wordpress Tutorial.
If you wish to report a bug, or if you are interested in having us mirror your free-software or open-source project, please feel free to contact us at mirror[@]dogado.de.

Type: Package
Title: Administrative Boundaries of Senegal
Version: 0.1.1
Description: The administrative boundaries of Senegal are provided at several levels, including regions, departments, arrondissements and communes. The Global Administrative Areas database, or 'GADM' https://gadm.org/, is the primary source for these layers. The dataset is complemented by the incorporation of additional geographic layers, such as localities, universities, roads, or health facility locations.
Depends: R (≥ 3.5.0), sf
URL: https://github.com/mapSenegal/mapSenegal
BugReports: https://github.com/mapSenegal/mapSenegal/issues
Suggests: mapsf
License: GPL-3
Encoding: UTF-8
RoxygenNote: 7.3.3
NeedsCompilation: no
Packaged: 2026-04-02 07:44:48 UTC; tim
Author: Timothée Giraud ORCID iD [cre, aut], Labaly Touré ORCID iD [aut], Hugues Pecout ORCID iD [ctb] (Logo), Robert J. Hijmans ORCID iD [cph] (GADM database)
Maintainer: Timothée Giraud <timothee.giraud@cnrs.fr>
Repository: CRAN
Date/Publication: 2026-04-07 07:50:02 UTC

Arrondissements

Description

Arrondissements of Senegal.

Usage

sn_arrondissements()

Value

An sf object is returned.

Codes and geometries have been extracted from the GADM database v4.1 (https://gadm.org/). Geometries precision has been fixed to 1 meter.

Examples

ardt <- sn_arrondissements()
plot(ardt)
if (require("mapsf")) {
  mf_map(ardt)
  mf_title("Arrondissements of Senegal")
}

Communes

Description

Communes of Senegal.

Usage

sn_communes()

Value

An sf object is returned.

Codes and geometries have been extracted from the GADM database v4.1 (https://gadm.org/). Geometries precision has been fixed to 1 meter.

Examples

com <- sn_communes()
plot(com)
if (require("mapsf")) {
  mf_map(com)
  mf_title("Communes of Senegal")
}

Country

Description

Senegal, level-0 entity.

Usage

sn_country()

Value

An sf object is returned.

Codes and geometries have been extracted from the GADM database v4.1 (https://gadm.org/). Geometries precision has been fixed to 1 meter.

Examples

senegal <- sn_country()
plot(senegal)
if (require("mapsf")) {
  mf_map(senegal)
  mf_title("Senegal")
}

Departments

Description

Departments of Senegal, level-2 entities.

Usage

sn_departments()

Value

An sf object is returned.

Codes and geometries have been extracted from the GADM database v4.1 (https://gadm.org/). Geometries precision has been fixed to 1 meter.

Examples

dep <- sn_departments()
plot(dep)
if (require("mapsf")) {
  mf_map(dep)
  mf_title("Departments of Senegal")
}

Health facilities

Description

Health facilities of Senegal

Usage

sn_health_facilities()

Value

An sf object is returned.

Direction des Travaux geographiques et de la cartographie, Senegal.

Examples

hf <- sn_health_facilities()
plot(hf)
if (require("mapsf")) {
  mf_map(hf, var = "TYPE", type = "symb", cex = 1, pal = "Dark 3", add = FALSE)
  mf_title("Health Facilities of Senegal")
}

Localities

Description

Localites of Senegal.

Usage

sn_localities()

Value

An sf object is returned.

Direction des Travaux geographiques et de la cartographie, Senegal.

Examples

loc <- sn_localities()
plot(loc)
if (require("mapsf")) {
  mf_map(loc)
  mf_title("Localities of Senegal")
}

Neighboring countries

Description

Neighboring countries of Senegal, level-0 entities.

Usage

sn_neighbors()

Value

An sf object is returned.

Codes and geometries have been extracted from the GADM database v4.1 (https://gadm.org/). Geometries precision has been fixed to 1 meter. Countries were cropped using a 100 km buffer around the Senegal bounding box.

Examples

neighbors <- sn_neighbors()
plot(neighbors)
if (require("mapsf")) {
  mf_map(neighbors)
  mf_label(neighbors, "NAME", halo = TRUE)
  mf_title("Senegal and Neighboring Countries")
}

Regions

Description

Regions of Senegal, level-1 entities.

Usage

sn_regions()

Value

An sf object is returned.

Codes and geometries have been extracted from the GADM database v4.1 (https://gadm.org/). Geometries precision has been fixed to 1 meter.

Examples

reg <- sn_regions()
plot(reg)
if (require("mapsf")) {
  mf_map(reg)
  mf_title("Regions of Senegal")
}

Roads

Description

Roads of Senegal.

Usage

sn_roads()

Value

An sf object is returned.

Direction des Travaux geographiques et de la cartographie, Senegal.

Examples

roads <- sn_roads()
plot(roads)
if (require("mapsf")) {
  mf_map(roads, var = "TYPE", type = "typo", lwd = 2)
  mf_title("Roads of Senegal")
}

Universities

Description

Universities of Senegal.

Usage

sn_universities()

Value

An sf object is returned.

Dataset gathered by Labaly Toure.

Examples

univ <- sn_universities()
plot(univ)
if (require("mapsf")) {
  mf_map(univ, var = "NB_STUDENTS", type = "prop", add = FALSE)
  mf_title("Universities of Senegal")
}

These binaries (installable software) and packages are in development.
They may not be fully stable and should be used with caution. We make no claims about them.
Health stats visible at Monitor.